@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::LayoutStartup;
 
-our $DATE = '2020-01-13'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $DATE = '2021-01-31'; # DATE
+our $VERSION = '0.017'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ Bencher::Scenario::LogGer::LayoutStartup
 
 =head1 VERSION
 
-This document describes version 0.016 of Bencher::Scenario::LogGer::LayoutStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2020-01-13.
+This document describes version 0.017 of Bencher::Scenario::LogGer::LayoutStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
 
 =head1 SYNOPSIS
 
@@ -69,11 +69,11 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Layout::JSON> 0.001
+L<Log::ger::Layout::JSON> 0.002
 
-L<Log::ger::Layout::LTSV> 0.003
+L<Log::ger::Layout::LTSV> 0.006
 
-L<Log::ger::Layout::Pattern> 0.004
+L<Log::ger::Layout::Pattern> 0.007
 
 L<Log::ger::Layout::YAML> 0.001
 
@@ -113,34 +113,34 @@ L<Log::ger::Layout::YAML>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 19.04 >>, OS kernel: I<< Linux version 5.0.0-37-generic >>.
+Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::LayoutStartup >>):
 
  #table1#
- +--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | participant  | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
- +--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | load-JSON    |      80.9 |     12.4  |                 0.00% |                92.49% | 4.5e-06 |      20 |
- | load-YAML    |      80.9 |     12.4  |                 0.01% |                92.47% | 4.7e-06 |      20 |
- | load-LTSV    |      83.1 |     12    |                 2.66% |                87.50% | 5.2e-06 |      20 |
- | load-Pattern |      83.4 |     12    |                 2.99% |                86.90% | 4.5e-06 |      20 |
- | baseline     |     156   |      6.42 |                92.49% |                 0.00% | 5.3e-06 |      20 |
- +--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ +--------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
+ | participant  | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ +--------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
+ | load-YAML    |       100 |      10   |                 0.00% |                66.78% |   0.00018 |      20 |
+ | load-JSON    |       100 |      10   |                 2.03% |                63.47% |   0.00012 |      20 |
+ | load-Pattern |       100 |       9   |                12.52% |                48.22% |   0.00011 |      20 |
+ | load-LTSV    |       120 |       8.4 |                18.49% |                40.76% | 6.6e-05   |      20 |
+ | baseline     |       170 |       6   |                66.78% |                 0.00% | 4.1e-05   |      20 |
+ +--------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::LayoutStartup --module-startup >>):
 
  #table2#
- +---------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
- | participant               | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
- +---------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
- | Log::ger::Layout::JSON    |     12.4  |              5.98 |                 0.00% |                93.01% | 5.3e-06 |      20 |
- | Log::ger::Layout::YAML    |     12.4  |              5.98 |                 0.11% |                92.81% | 7.2e-06 |      21 |
- | Log::ger::Layout::LTSV    |     12.1  |              5.68 |                 2.28% |                88.71% | 8.5e-06 |      20 |
- | Log::ger::Layout::Pattern |     12    |              5.58 |                 3.22% |                87.00% | 5.5e-06 |      24 |
- | perl -e1 (baseline)       |      6.42 |              0    |                93.01% |                 0.00% | 3.1e-06 |      20 |
- +---------------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ +---------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ | participant               | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ +---------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ | Log::ger::Layout::YAML    |        10 |                 4 |                 0.00% |                98.14% |   0.00036 |      20 |
+ | Log::ger::Layout::JSON    |        10 |                 4 |                 3.57% |                91.32% |   0.00023 |      20 |
+ | Log::ger::Layout::LTSV    |        10 |                 4 |                12.85% |                75.57% |   0.00021 |      20 |
+ | Log::ger::Layout::Pattern |        10 |                 4 |                13.71% |                74.25% |   0.00028 |      20 |
+ | perl -e1 (baseline)       |         6 |                 0 |                98.14% |                 0.00% | 6.5e-05   |      20 |
+ +---------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -167,7 +167,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
