@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2020-01-13'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $DATE = '2021-01-31'; # DATE
+our $VERSION = '0.017'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
     modules => {
         'Log::ger' => {version=>'0.023'},
-        'Log::ger::Plugin::MultilevelLog' => {},
+        'Log::ger::Format::MultilevelLog' => {},
         'Log::ger::Plugin::OptAway' => {},
         'Log::Any' => {},
         'Log::Fast' => {},
@@ -38,12 +38,12 @@ our $scenario = {
             perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..100_000) { log_trace(q[]) }'],
         },
         {
-            name => 'Log::ger+LGP:MutilevelLog-100k_log_trace',
-            perl_cmdline_template => ['-MLog::ger::Plugin=MultilevelLog', '-MLog::ger', '-e', 'for(1..100_000) { log("trace", q[]) }'],
+            name => 'Log::ger+LGF:MutilevelLog-100k_log_trace',
+            perl_cmdline_template => ['-MLog::ger::Format=MultilevelLog', '-MLog::ger', '-e', 'for(1..100_000) { log("trace", q[]) }'],
         },
         {
             name => 'Log::ger+LGP:MutilevelLog-100k_log_6',
-            perl_cmdline_template => ['-MLog::ger::Plugin=MultilevelLog', '-MLog::ger', '-e', 'for(1..100_000) { log(6, q[]) }'],
+            perl_cmdline_template => ['-MLog::ger::Format=MultilevelLog', '-MLog::ger', '-e', 'for(1..100_000) { log(6, q[]) }'],
         },
 
         {
@@ -124,7 +124,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.016 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2020-01-13.
+This document describes version 0.017 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2021-01-31.
 
 =head1 SYNOPSIS
 
@@ -142,29 +142,29 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::Any> 1.707
+L<Log::Any> 1.708
 
 L<Log::Contextual> 0.008001
 
 L<Log::Contextual::SimpleLogger> 0.008001
 
-L<Log::Dispatch> 2.68
+L<Log::Dispatch> 2.70
 
-L<Log::Dispatch::Null> 2.68
+L<Log::Dispatch::Null> 2.70
 
-L<Log::Dispatchouli> 2.019
+L<Log::Dispatchouli> 2.022
 
 L<Log::Fast> v2.0.1
 
-L<Log::Log4perl> 1.49
+L<Log::Log4perl> 1.53
 
 L<Log::Log4perl::Tiny> 1.4.0
 
-L<Log::ger> 0.028
+L<Log::ger> 0.038
 
-L<Log::ger::Plugin::MultilevelLog> 0.028
+L<Log::ger::Format::MultilevelLog> 0.038
 
-L<Log::ger::Plugin::OptAway> 0.006
+L<Log::ger::Plugin::OptAway> 0.009
 
 L<Mojo::Log>
 
@@ -196,11 +196,11 @@ Command line:
 
 
 
-=item * Log::ger+LGP:MutilevelLog-100k_log_trace (command)
+=item * Log::ger+LGF:MutilevelLog-100k_log_trace (command)
 
 Command line:
 
- #TEMPLATE: #perl -MLog::ger::Plugin=MultilevelLog -MLog::ger -e for(1..100_000) { log("trace", q[]) }
+ #TEMPLATE: #perl -MLog::ger::Format=MultilevelLog -MLog::ger -e for(1..100_000) { log("trace", q[]) }
 
 
 
@@ -208,7 +208,7 @@ Command line:
 
 Command line:
 
- #TEMPLATE: #perl -MLog::ger::Plugin=MultilevelLog -MLog::ger -e for(1..100_000) { log(6, q[]) }
+ #TEMPLATE: #perl -MLog::ger::Format=MultilevelLog -MLog::ger -e for(1..100_000) { log(6, q[]) }
 
 
 
@@ -320,7 +320,7 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 19.04 >>, OS kernel: I<< Linux version 5.0.0-37-generic >>.
+Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 19 >>, OS kernel: I<< Linux version 5.3.0-68-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
@@ -328,24 +328,24 @@ Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
  +------------------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant                              | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +------------------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Log::Dispatch::Null-100k_debug           |      2    |     510   |                 0.00% |              3860.13% |   0.0014  |       6 |
- | Log::Contextual+Log4perl-100k_trace      |      2.2  |     450   |                12.15% |              3430.94% |   0.0012  |       6 |
- | Log::Contextual+SimpleLogger-100k_trace  |      2.3  |     440   |                15.55% |              3327.19% |   0.0014  |       6 |
- | Log::Dispatchouli-100k_debug             |      6.4  |     160   |               225.42% |              1116.91% |   0.00025 |       6 |
- | Mojo::Log-100k_debug                     |      7.03 |     142   |               257.41% |              1008.01% | 6.3e-05   |       6 |
- | Log::Log4perl::Tiny-100k_trace           |     10.1  |      98.6 |               415.45% |               668.28% |   7e-05   |       6 |
- | Log::Fast-100k_is_debug                  |     17    |      60   |               741.35% |               370.69% | 7.7e-05   |       6 |
- | Log::Any-null_adapter-100k_log_trace     |     16.7  |      59.8 |               750.22% |               365.77% | 2.3e-05   |       8 |
- | Log::Log4perl-easy-100k_trace            |     19    |      52   |               880.85% |               303.74% |   0.00018 |       6 |
- | Log::Any-null_adapter-100k_is_trace      |     24.7  |      40.5 |              1154.43% |               215.69% | 3.6e-05   |       6 |
- | Log::Any-no_adapter-100k_is_trace        |     25    |      40.1 |              1168.66% |               212.15% | 4.5e-06   |       6 |
- | Log::Fast-100k_DEBUG                     |     27    |      37   |              1281.68% |               186.62% | 5.9e-05   |       6 |
- | Log::Any-no_adapter-100k_log_trace       |     42    |      24   |              2012.16% |                87.49% | 4.7e-05   |       6 |
- | Log::ger+LGP:OptAway-100k_log_trace      |     47.2  |      21.2 |              2300.93% |                64.94% | 1.8e-05   |       7 |
- | Log::ger+LGP:MutilevelLog-100k_log_trace |     52.6  |      19   |              2572.82% |                48.16% | 1.7e-05   |       7 |
- | Log::ger+LGP:MutilevelLog-100k_log_6     |     52.7  |      19   |              2579.73% |                47.78% | 4.9e-06   |       6 |
- | Log::ger-100k_log_trace                  |     75.8  |      13.2 |              3752.06% |                 2.81% | 1.1e-05   |       6 |
- | Log::ger-100k_log_is_trace               |     78    |      13   |              3860.13% |                 0.00% | 2.8e-05   |       6 |
+ | Log::Dispatch::Null-100k_debug           |      2.3  |     434   |                 0.00% |              4948.67% |   0.00039 |       6 |
+ | Log::Contextual+Log4perl-100k_trace      |      2.6  |     390   |                12.11% |              4403.15% |   0.0036  |       7 |
+ | Log::Contextual+SimpleLogger-100k_trace  |      2.71 |     369   |                17.77% |              4186.72% |   0.00032 |       6 |
+ | Log::Dispatchouli-100k_debug             |      7.7  |     130   |               234.31% |              1410.19% |   0.00066 |       6 |
+ | Mojo::Log-100k_debug                     |      8.4  |     120   |               266.62% |              1277.10% |   0.00014 |       6 |
+ | Log::Log4perl::Tiny-100k_trace           |     12    |      85   |               409.68% |               890.56% |   0.00022 |       6 |
+ | Log::Fast-100k_is_debug                  |     19    |      52   |               738.98% |               501.76% |   0.00047 |       6 |
+ | Log::Any-null_adapter-100k_log_trace     |     19    |      51   |               744.52% |               497.82% |   0.00035 |       7 |
+ | Log::Log4perl-easy-100k_trace            |     23    |      44   |               878.68% |               415.87% |   0.00029 |       6 |
+ | Log::Any-no_adapter-100k_is_trace        |     28    |      36   |              1113.10% |               316.18% |   0.00021 |       6 |
+ | Log::Any-null_adapter-100k_is_trace      |     28    |      36   |              1122.77% |               312.89% |   0.00019 |       6 |
+ | Log::Fast-100k_DEBUG                     |     30    |      30   |              1280.57% |               265.69% |   0.00039 |       6 |
+ | Log::Any-no_adapter-100k_log_trace       |     50    |      20   |              1979.24% |               142.81% |   0.00025 |       7 |
+ | Log::ger+LGP:OptAway-100k_log_trace      |     54    |      19   |              2241.63% |               115.60% | 2.1e-05   |       6 |
+ | Log::ger+LGF:MutilevelLog-100k_log_trace |     59    |      17   |              2453.20% |                97.74% | 7.1e-05   |       7 |
+ | Log::ger+LGP:MutilevelLog-100k_log_6     |     60    |      20   |              2579.52% |                88.42% |   0.00019 |       6 |
+ | Log::ger-100k_log_trace                  |    100    |       9   |              4496.25% |                 9.84% |   0.00015 |       6 |
+ | Log::ger-100k_log_is_trace               |    120    |       8.6 |              4948.67% |                 0.00% | 2.2e-05   |       7 |
  +------------------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
 
@@ -373,7 +373,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
